@@ -12,7 +12,6 @@ from typing import Optional
 from typing import Set
 from typing import Type
 from typing import TypeVar
-from typing import Union
 
 from atomic_write_path import atomic_write_path
 
@@ -21,21 +20,23 @@ from workflows.task import Task
 
 
 T = TypeVar("T")
+_DEFAULT_OVERWRITE = False
 
 
 class FileTask(Task[T]):
-    def __call__(self: FileTask[T], *, overwrite: bool = True) -> T:
+    def __call__(self: FileTask[T], *, overwrite: bool = _DEFAULT_OVERWRITE) -> T:
+        path = self.path()
         if overwrite:
             out = self.compute()
-            with atomic_write_path(self.path(), overwrite=True) as temp:
+            with atomic_write_path(path, overwrite=True) as temp:
                 self.write(out, temp)
             return out
         else:
             try:
-                return self.read(self.path())
+                return self.read(path)
             except FileNotFoundError:
                 out = self.compute()
-                with atomic_write_path(self.path(), overwrite=False) as temp:
+                with atomic_write_path(path, overwrite=False) as temp:
                     self.write(out, temp)
                 return out
 
@@ -44,15 +45,15 @@ class FileTask(Task[T]):
         raise NotImplementedError
 
     @abstractmethod
-    def path(self: FileTask) -> Union[Path, str]:
+    def path(self: FileTask) -> Path:
         raise NotImplementedError
 
     @abstractmethod  # noqa: U100
-    def read(self: FileTask[T], path: Union[Path, str]) -> T:  # noqa: U100
+    def read(self: FileTask[T], path: Path) -> T:  # noqa: U100
         raise NotImplementedError
 
     @abstractmethod  # noqa: U100
-    def write(self: FileTask, value: T, path: Union[Path, str]) -> None:  # noqa: U100
+    def write(self: FileTask, value: T, path: Path) -> None:  # noqa: U100
         raise NotImplementedError
 
     @classmethod
@@ -61,7 +62,7 @@ class FileTask(Task[T]):
         tasks: Iterable[FileTask],
         *,
         executor: Optional[Executor] = None,
-        overwrite: bool = False,
+        overwrite: bool = _DEFAULT_OVERWRITE,
     ) -> None:
         tasks: Set[FileTask] = reduce(
             lambda x, y: x | {y} | y.get_dependencies(recurse=True), tasks, set(),
